@@ -15,14 +15,14 @@ class FeiShuPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to FeiShu.
     """
-    author = 'ansheng'
-    author_url = 'https://github.com/anshengme/sentry-dingding'
+    author = 'feng.chen'
+    author_url = 'https://github.com/jnchenfeng/sentry_feishu'
     version = sentry_feishu.VERSION
     description = 'Send error counts to FeiShu.'
     resource_links = [
-        ('Source', 'https://github.com/anshengme/sentry-dingding'),
-        ('Bug Tracker', 'https://github.com/anshengme/sentry-dingding/issues'),
-        ('README', 'https://github.com/anshengme/sentry-dingding/blob/master/README.md'),
+        ('Source', 'https://github.com/jnchenfeng/sentry_feishu'),
+        ('Bug Tracker', 'https://github.com/jnchenfeng/sentry_feishu/issues'),
+        ('README', 'https://github.com/jnchenfeng/sentry_feishu/blob/master/README.md'),
     ]
 
     slug = 'FeiShu'
@@ -52,14 +52,15 @@ class FeiShuPlugin(NotificationPlugin):
 
         access_token = self.get_option('access_token', group.project)
         send_url = FeiShuTalk_API.format(token=access_token)
-        title = u"New alert from {}".format(event.project.slug)
+        project = event.group.project
+        title = u"New alert from {}".format(project.slug)
 
         data = {
             "title": title,
             "text": u"#### {title} \n > {message} [href]({url})".format(
                 title=title,
                 message=event.message,
-                url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
+                url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
             )
         }
         requests.post(
